@@ -1,7 +1,10 @@
 """
 Python Wechaty - https://github.com/wechaty/python-wechaty
 
-2020-now @copyright Wechaty
+Authors:    Huan LI (李卓桓) <https://github.com/huan>
+            Jingjing WU (吴京京) <https://github.com/wj-Mcat>
+
+2018-now @copyright Wechaty
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
@@ -15,16 +18,24 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 """
+from __future__ import annotations
+
 from typing import (
+    TYPE_CHECKING,
     # overload,
     # cast,
     Optional,
 )
-from wechaty_puppet import Puppet
+
 from .config import (
     logging
 )
-from .wechaty import Wechaty
+
+# pylint:disable=R0401
+if TYPE_CHECKING:
+    from wechaty_puppet import Puppet
+    from .wechaty import Wechaty
+
 
 log = logging.getLogger('Accessory')
 
@@ -52,14 +63,32 @@ class Accessory:
             raise AttributeError('can not set twice')
         cls._wechaty = new_wechaty
 
-    def puppet(self):
+    @classmethod
+    def get_puppet(cls) -> Puppet:
+        """doc"""
+        if cls._puppet is None:
+            raise AttributeError('puppet not found')
+        return cls._puppet
+
+    @classmethod
+    def get_wechaty(cls) -> Wechaty:
+        """doc"""
+        if cls._wechaty is None:
+            raise AttributeError('wechaty not found')
+        return cls._wechaty
+
+    @property
+    def puppet(self) -> Puppet:
         """doc"""
         if self._puppet is None:
             raise AttributeError('puppet not set')
         return self._puppet
 
-    def wechaty(self):
-        """doc"""
+    @property
+    def wechaty(self) -> Wechaty:
+        """
+        instance property
+        """
         if self._wechaty is None:
             raise AttributeError('wechaty not set')
         return self._wechaty
