@@ -3,27 +3,24 @@ Huan(202003):
     Translated from TypeScript to Python
     See: https://github.com/wechaty/wechaty/blob/master/src/accessory.spec.ts
 """
+from __future__ import annotations
+
 from typing import (
-    cast,
+    Any,
     Type,
+    cast,
 )
 import pytest   # type: ignore
 
-from wechaty import (
-    Wechaty,
-)
-from wechaty_puppet import (
-    Puppet,
-)
 from .accessory import (
     Accessory,
 )
 
-EXPECTED_PUPPET1 = cast(Puppet, {'p': 1})
-EXPECTED_PUPPET2 = cast(Puppet, {'p': 2})
+EXPECTED_PUPPET1 = cast(Any, {'p': 1})
+EXPECTED_PUPPET2 = cast(Any, {'p': 2})
 
-EXPECTED_WECHATY1 = cast(Wechaty, {'w': 1})
-EXPECTED_WECHATY2 = cast(Wechaty, {'w': 1})
+EXPECTED_WECHATY1 = cast(Any, {'w': 1})
+EXPECTED_WECHATY2 = cast(Any, {'w': 1})
 
 
 def get_user_class() -> Type[Accessory]:
@@ -166,3 +163,43 @@ def test_accessory_set_twice(
     with pytest.raises(Exception) as e:
         user_class.set_wechaty(EXPECTED_WECHATY1)
     assert str(e.value) == 'can not set twice'
+
+
+def test_accessory_classmethod_access_puppet():
+    """
+    docstring
+    """
+    user_class1 = get_user_class()
+    user_class2 = get_user_class()
+
+    user_class1.set_puppet(EXPECTED_PUPPET1)
+    user_class2.set_puppet(EXPECTED_PUPPET2)
+
+    assert user_class1.get_puppet() == EXPECTED_PUPPET1 , \
+        'user_class1 should get the puppet from static value'
+
+    assert user_class2.get_puppet() == EXPECTED_PUPPET2, \
+        'user_class2 should get the puppet from static value'
+
+    assert user_class1.get_puppet() != user_class2.get_puppet(), \
+        'user_class1 & user_class2 get_puppet() should be different'
+
+
+def test_accessory_classmethod_access_wechaty():
+    """
+    docstring
+    """
+    user_class1 = get_user_class()
+    user_class2 = get_user_class()
+
+    user_class1.set_wechaty(EXPECTED_WECHATY1)
+    user_class2.set_wechaty(EXPECTED_WECHATY2)
+
+    assert user_class1.get_wechaty() == EXPECTED_WECHATY1 , \
+        'user_class1 should get the wechaty from static value'
+
+    assert user_class2.get_wechaty() == EXPECTED_WECHATY2, \
+        'user_class2 should get the puppet from static value'
+
+    # assert user_class1.get_wechaty() != user_class2.get_wechaty(), \
+    #     'user_class1 & user_class2 get_wechaty() should be different'
