@@ -1,21 +1,22 @@
 """
-
 Python Wechaty - https://github.com/wechaty/python-wechaty
 
-2020-now @copyright Wechaty
+Authors:    Huan LI (李卓桓) <https://github.com/huan>
+            Jingjing WU (吴京京) <https://github.com/wj-Mcat>
 
-Licensed under the Apache License, Version 2.0 (the "License");
+2020-now @ Copyright Wechaty
+
+Licensed under the Apache License, Version 2.0 (the 'License');
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at
 
-    http://www.apache.org/licenses/LICENSE-2.0
+http://www.apache.org/licenses/LICENSE-2.0
 
 Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
+distributed under the License is distributed on an 'AS IS' BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
-
 """
 #
 # Python 3.7: PEP 563: Postponed Evaluation of Annotations
@@ -23,8 +24,8 @@ limitations under the License.
 from __future__ import annotations
 
 from typing import (
-    cast,
-    ClassVar,
+    # TypeVar,
+    # cast,
     Optional,
     Type,
     # Union,
@@ -33,6 +34,12 @@ from typing import (
 from .config import (
     logging,
 )
+from .user import (
+    Contact,
+    Friendship,
+    Message,
+    Tag,
+)
 
 log = logging.getLogger('Wechaty')
 
@@ -56,17 +63,20 @@ class Wechaty:
     docstring
     """
 
-    _global_instance: ClassVar[Optional[Wechaty]] = None
+    _global_instance: Optional['Wechaty'] = None
 
     def __init__(self):
         """
         docstring
         """
         log.info('__init__()')
-        raise NotImplementedError
+        self.Tag = Tag
+        self.Contact = Contact
+        self.Friendship = Friendship
+        self.Message = Message
 
     @classmethod
-    def instance(cls: Type[Wechaty]) -> Wechaty:
+    def instance(cls: Type['Wechaty']) -> 'Wechaty':
         """
         get or create global wechaty instance
         :return:
@@ -77,9 +87,14 @@ class Wechaty:
             cls._global_instance = cls()
 
         # Huan(202003): how to remove cast?
-        return cast(Wechaty, cls._global_instance)
+        return cls._global_instance
+        # return cast(Wechaty, cls._global_instance)
         # return cls._global_instance
 
+    async def name(self) -> str:
+        """name"""
+        return 'to be imp'
+
     async def start(self) -> None:
         """
         start the wechaty
